<div align="center">

<h1 align="center">
🍰xhs
</h1>

[![PyPI](https://img.shields.io/pypi/v/xhs?label=xhs)](https://pypi.org/project/xhs/)
[![](https://static.pepy.tech/badge/xhs)](https://pepy.tech/project/xhs)
[![](https://img.shields.io/github/license/ReaJason/xhs)](https://github.com/ReaJason/xhs/blob/master/LICENSE)
[![Tencent QQ](https://img.shields.io/badge/QQ-668689006-%2312B7F5?logo=tencentqq&logoColor=white)](https://qm.qq.com/cgi-bin/qm/qr?k=ClAygjOnEiOotOGzu6yQ8ZhWekrArAXf&jump_from=webapi&authKey=Gje6CcffTA1untyXfv/Pitt4aXQ0m2I/4p0PeTaRYCueTgwM5NwT842miLW4zGL/)
<br /> [![](https://github.com/ReaJason/xhs/actions/workflows/doc.yml/badge.svg)](https://reajason.github.io/xhs/)
[![](https://github.com/ReaJason/xhs/actions/workflows/test.yml/badge.svg)](https://github.com/ReaJason/xhs/actions/workflows/test.yml)
[![](https://github.com/ReaJason/xhs/actions/workflows/pypi.yml/badge.svg)](https://github.com/ReaJason/xhs/actions/workflows/pypi.yml)

</div>

> **Warning**
>
> The primary purpose of this repository is to practice my Python skills. It is important to note that web crawling may
> be considered illegal, and therefore, it is crucial to refrain from exerting any pressure or engaging in unauthorized
> activities on websites.

**xhs** is a crawling tool designed to extract data from [xiaohongshu website](https://www.xiaohongshu.com/explore)

## Usage

xhs is available on PyPI:

```console
$ python -m pip install xhs
```

if you want the latest version, you can install from git:

```console
$ python -m pip install git+https://github.com/ReaJason/xhs
```

### Basic Usage

> maybe now is more complex, Thanks [@NanmiCoder](https://github.com/NanmiCoder)

Please find in the [document](https://reajason.github.io/xhs/basic)

